@@ -63,7 +63,7 @@
 #define KIRIGAMI2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIRIGAMI2_NO_DEPRECATED
-#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KIRIGAMI2_NO_DEPRECATED_WARNINGS
 #  define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0
@@ -73,7 +73,7 @@
 #  ifdef KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -92,6 +92,12 @@
 #else
 #  define KIRIGAMI2_DEPRECATED_VERSION_5_80(text)
 #endif
+
+#if KIRIGAMI2_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KIRIGAMI2_DEPRECATED_VERSION_5_86(text) KIRIGAMI2_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIRIGAMI2_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KIRIGAMI2_DEPRECATED_VERSION_5(minor, text)      KIRIGAMI2_DEPRECATED_VERSION_5_##minor(text)
 #define KIRIGAMI2_DEPRECATED_VERSION(major, minor, text) KIRIGAMI2_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KIRIGAMI2_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIRIGAMI2_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -134,7 +140,7 @@
 #define KIRIGAMI2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIRIGAMI2_NO_DEPRECATED
-#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KIRIGAMI2_NO_DEPRECATED_WARNINGS
 #  define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0
@@ -144,7 +150,7 @@
 #  ifdef KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE KIRIGAMI2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KIRIGAMI2_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -163,6 +169,12 @@
 #else
 #  define KIRIGAMI2_DEPRECATED_VERSION_5_80(text)
 #endif
+
+#if KIRIGAMI2_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KIRIGAMI2_DEPRECATED_VERSION_5_86(text) KIRIGAMI2_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIRIGAMI2_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KIRIGAMI2_DEPRECATED_VERSION_5(minor, text)      KIRIGAMI2_DEPRECATED_VERSION_5_##minor(text)
 #define KIRIGAMI2_DEPRECATED_VERSION(major, minor, text) KIRIGAMI2_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KIRIGAMI2_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIRIGAMI2_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
